Package: rio
Type: Package
Title: A Swiss-Army Knife for Data I/O
Version: 1.3.0
Authors@R: c(person("Jason", "Becker", role = "aut", email = "jason@jbecker.co"),
             person("Chung-hong", "Chan", role = c("aut", "cre"), email = "chainsawtiney@gmail.com",
	     	     comment = c(ORCID = "0000-0002-6232-7530")),
             person("David", "Schoch", email = "david@schochastics.net", role = c("aut"),
                     comment = c(ORCID = "0000-0003-2952-4812")),
             person("Geoffrey CH", "Chan", role = "ctb", email = "gefchchan@gmail.com"),
             person("Thomas J.", "Leeper",
                    role = "aut", 
                    email = "thosjleeper@gmail.com",
                    comment = c(ORCID = "0000-0003-4097-6326")),
             person("Christopher", "Gandrud", role = "ctb"),
             person("Andrew", "MacDonald", role = "ctb"),
             person("Ista", "Zahn", role = "ctb"),
             person("Stanislaus", "Stadlmann", role = "ctb"),
             person("Ruaridh", "Williamson", role = "ctb", email = "ruaridh.williamson@gmail.com"),
             person("Patrick", "Kennedy", role = "ctb"),
             person("Ryan", "Price", email = "ryapric@gmail.com", role = "ctb"),
             person("Trevor L", "Davis", email = "trevor.l.davis@gmail.com", role = "ctb"),
             person("Nathan", "Day", email = "nathancday@gmail.com", role = "ctb"),
             person("Bill", "Denney",
                    email="wdenney@humanpredictions.com",
                    role="ctb",
                    comment=c(ORCID="0000-0002-5759-428X")),
             person("Alex", "Bokov", email = "alex.bokov@gmail.com", role = "ctb",
                    comment=c(ORCID="0000-0002-0511-9815")),
             person("Hugo", "Gruson", role = "ctb", comment = c(ORCID = "0000-0002-4094-1476")),
             person("Jacob", "Mears", role = "ctb"))
Description: Streamlined data import and export by making assumptions that
    the user is probably willing to make: 'import()' and 'export()' determine
    the data format from the file extension, reasonable defaults are used for
    data import and export, web-based import is natively supported (including
    from SSL/HTTPS), compressed files can be read directly, and fast import
    packages are used where appropriate. An additional convenience function,
    'convert()', provides a simple method for converting between file types.
URL: https://gesistsa.github.io/rio/, https://github.com/gesistsa/rio
BugReports: https://github.com/gesistsa/rio/issues
Depends: R (>= 4.0)
Imports: tools, stats, utils, foreign, haven (>= 1.1.2), curl (>= 0.6),
        data.table (>= 1.11.2), readxl (>= 0.1.1), tibble, writexl,
        lifecycle, R.utils (>= 2.13.0), readr
Suggests: datasets, bit64, testthat, knitr, magrittr, clipr, fst,
        hexView, jsonlite, pzfx, readODS (>= 2.1.0), rmarkdown, rmatio,
        xml2 (>= 1.2.0), yaml, arrow (>= 0.17.0), stringi, withr,
        nanoparquet, qs2 (>= 0.1.5)
License: GPL-2
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.3.2
Config/Needs/website: gesistsa/tsatemplate
NeedsCompilation: no
Packaged: 2026-04-01 15:37:49 UTC; chainsawriot
Author: Jason Becker [aut],
  Chung-hong Chan [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-6232-7530>),
  David Schoch [aut] (ORCID: <https://orcid.org/0000-0003-2952-4812>),
  Geoffrey CH Chan [ctb],
  Thomas J. Leeper [aut] (ORCID: <https://orcid.org/0000-0003-4097-6326>),
  Christopher Gandrud [ctb],
  Andrew MacDonald [ctb],
  Ista Zahn [ctb],
  Stanislaus Stadlmann [ctb],
  Ruaridh Williamson [ctb],
  Patrick Kennedy [ctb],
  Ryan Price [ctb],
  Trevor L Davis [ctb],
  Nathan Day [ctb],
  Bill Denney [ctb] (ORCID: <https://orcid.org/0000-0002-5759-428X>),
  Alex Bokov [ctb] (ORCID: <https://orcid.org/0000-0002-0511-9815>),
  Hugo Gruson [ctb] (ORCID: <https://orcid.org/0000-0002-4094-1476>),
  Jacob Mears [ctb]
Maintainer: Chung-hong Chan <chainsawtiney@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-02 07:40:02 UTC
