# Generated by roxygen2: do not edit by hand

S3method(.export,rio_arff)
S3method(.export,rio_clipboard)
S3method(.export,rio_csv)
S3method(.export,rio_csv2)
S3method(.export,rio_csvy)
S3method(.export,rio_dbf)
S3method(.export,rio_dta)
S3method(.export,rio_dump)
S3method(.export,rio_feather)
S3method(.export,rio_fods)
S3method(.export,rio_fst)
S3method(.export,rio_fwf)
S3method(.export,rio_html)
S3method(.export,rio_json)
S3method(.export,rio_matlab)
S3method(.export,rio_ods)
S3method(.export,rio_parquet)
S3method(.export,rio_psv)
S3method(.export,rio_pzfx)
S3method(.export,rio_qs2)
S3method(.export,rio_r)
S3method(.export,rio_rda)
S3method(.export,rio_rdata)
S3method(.export,rio_rds)
S3method(.export,rio_sas7bdat)
S3method(.export,rio_sav)
S3method(.export,rio_tsv)
S3method(.export,rio_txt)
S3method(.export,rio_xlsx)
S3method(.export,rio_xml)
S3method(.export,rio_xpt)
S3method(.export,rio_yml)
S3method(.export,rio_zsav)
S3method(.import,rio_arff)
S3method(.import,rio_clipboard)
S3method(.import,rio_csv)
S3method(.import,rio_csv2)
S3method(.import,rio_csvy)
S3method(.import,rio_dat)
S3method(.import,rio_dbf)
S3method(.import,rio_dif)
S3method(.import,rio_dta)
S3method(.import,rio_dump)
S3method(.import,rio_eviews)
S3method(.import,rio_feather)
S3method(.import,rio_fods)
S3method(.import,rio_fortran)
S3method(.import,rio_fst)
S3method(.import,rio_fwf)
S3method(.import,rio_html)
S3method(.import,rio_json)
S3method(.import,rio_matlab)
S3method(.import,rio_mtp)
S3method(.import,rio_ods)
S3method(.import,rio_parquet)
S3method(.import,rio_psv)
S3method(.import,rio_pzfx)
S3method(.import,rio_qs2)
S3method(.import,rio_r)
S3method(.import,rio_rda)
S3method(.import,rio_rdata)
S3method(.import,rio_rds)
S3method(.import,rio_rec)
S3method(.import,rio_sas7bdat)
S3method(.import,rio_sav)
S3method(.import,rio_spss)
S3method(.import,rio_syd)
S3method(.import,rio_tsv)
S3method(.import,rio_txt)
S3method(.import,rio_xls)
S3method(.import,rio_xlsm)
S3method(.import,rio_xlsx)
S3method(.import,rio_xml)
S3method(.import,rio_xpt)
S3method(.import,rio_yml)
S3method(.import,rio_zsav)
S3method(characterize,data.frame)
S3method(characterize,default)
S3method(factorize,data.frame)
S3method(factorize,default)
export(characterize)
export(convert)
export(export)
export(export_list)
export(factorize)
export(gather_attrs)
export(get_ext)
export(get_info)
export(import)
export(import_list)
export(install_formats)
export(show_unsupported_formats)
export(spread_attrs)
