# Teletypewriter

Rust crate to create a pseudoterminal (pty) that emulates a tty, which is a command in Unix and Unix-like operating systems to print the file name of the terminal connected to standard input. tty stands for TeleTYpewriter. This project is created and maintained for [Rio terminal](https://github.com/raphamorim/rio) purposes but feel free to use it.
