---
layout: post
title: 'Rio 0.1.x is here'
date: 2024-06-12 12:34
description: 'Font ligatures, emojis'
categories: windows macos linux
draft: true
---

import { Tweet } from 'react-tweet';

Font ligatures, emojis, new macos client.

## Support to Font ligatures

Demo usage of Rio terminal on MacOS using [Fira Code](https://fonts.google.com/specimen/Fira+Code) and font ligatures enabled:

![Font ligatures demo](/assets/posts/0.1.0/demo-rio.png)

## Support to Emojis

TODO

## Support to MacOS open file URLs

![Macos open files](/assets/posts/0.1.0/rio-demo-open-file.gif)

## Terminal integration with VS Code (MacOS and Windows)

![Macos open folders](/assets/posts/0.1.0/rio-demo-open-folder.gif)