---
title: 'Features'
language: 'en'
---

Rio is available for Microsoft Windows, Linux distros, FreeBSD and Apple MacOS.

Short introduction of Rio terminal features.

- [Vi mode](/docs/features/vi-mode)
- [Hyperlinks](/docs/features/hyperlinks)
- [iTerm2 image protocol](/docs/features/iterm2-image-protocol)
- [Kitty keyboard protocol](/docs/features/kitty-keyboard-protocol)
- [Rio is fast](/docs/features/rio-is-fast)
- [Adaptive theme](/docs/features/adaptive-theme)
- [Multi windows](/docs/features/multi-windows)
- [Navigation](/docs/config/navigation)
- [Color automation for navigation](/docs/features/color-automation-for-navigation)
- [Sixel protocol](/docs/features/sixel-protocol)
- [Spawn or Fork](/docs/features/spawn-or-fork)

Note: Many other features are in development.
