---
title: 'Spawn or Fork'
language: 'en'
---

In POSIX-based systems, Rio spawn processes instead of forking due to some compatibility issues between platforms.

However you can also switch from spawn to fork, forking a process is faster than spawning a process.

See how to configure it in the advanced section [here](/docs/config).
