---
title: 'Navigation'
language: 'en'
---

Rio support different types of navigation modes:

<p>
<img alt="Demo TopTab" src="/rio/assets/features/demo-top-tab.png" width="48%"/>
<img alt="Demo native tabs" src="/rio/assets/posts/0.0.17/demo-native-tabs.png" width="48%"/>
</p>

<p>
<img alt="Demo Bookmark" src="https://miro.medium.com/v2/resize:fit:1400/format:webp/1*gMLWcZkniSHUT6Cb7L06Gg.png" width="48%" />
<img alt="Demo BottomTab" src="/rio/assets/features/demo-bottom-tab.png" width="48%"/>
</p>

See more about it [here](/docs/config/navigation).
