---
layout: post
title: 'Release 0.0.6'
date: 2023-06-07 10:34:14 +0200
categories: macos linux release
description: 'Tabs support, underline and beam cursor, text styles and many bug fixes.'
---

import { Tweet } from 'react-tweet';

# Tabs support, underline and beam cursor, text styles and many bug fixes.

Rio release 0.0.6 is finally here, there's a lot of updates to cover so let's get started. I also would like to remind you that Rio is still unstable. This release adds a lot of bug fixes and feature additions in order to make Rio terminal stable.

## Underline and strikethrough style

Support to text styling as such "Underline" and "Strikethrough".

## Tabs support

Tabs has been added to Rio terminal for macos and linux platform.

The shortcuts:

- Create tab: Logo key (Command in macos) + T.
- Close tab: Logo key (Command in macos) + W.
- Switch tab: Control key + Tab key.

Below you can see an example of usage:

<Tweet id="1664585160958922755" />

Note: There's a limit of maximum of 6 tabs for now.

## Support to Beam and Underline cursors

Beam and underline cursor support has been added to Rio terminal. Also, block cursor and IME state allow a character to be visible.

<Tweet id="1664146499398139906" />

## Changelog

- Fix: support to clipboard in linux by [@joseemds](https://github.com/joseemds).
- Font style for custom fonts by [@OlshaMB](https://github.com/OlshaMB) (closed [#80](https://github.com/raphamorim/rio/issues/80) and [#81](https://github.com/raphamorim/rio/issues/81))
- Text styles Underline and Strikethrough (closed [#79](https://github.com/raphamorim/rio/issues/79)).
- Update default colors for tabs/tabs-active.
- Tabs support.
- Fix rendering tab and hidden chars by replacing to space by [@niuez](https://github.com/niuez), (closed [#56](https://github.com/raphamorim/rio/issues/56)).
- Block cursor hover a character and still allow it to be visible.
- Support to caret Beam and Underline cursor [#67](https://github.com/raphamorim/rio/issues/67) by [@niuez](https://github.com/niuez).
- Fix panics if custom font is not found [#68](https://github.com/raphamorim/rio/issues/68).
- MacOs ignore alt key in cntrlseq (same behavior as Terminal.app, Hyper, iTerm and etecetera).
