---
title: 'Linux'
language: 'en'
---

Installation options:

- Alpine Linux package: [pkgs.alpinelinux.org/packages?name=rio](https://pkgs.alpinelinux.org/packages?name=rio)
- Arch Linux package: [archlinux.org/packages/extra/x86_64/rio](https://archlinux.org/packages/extra/x86_64/rio)
- Nix package: [NixOS/nixpkgs/rio](https://github.com/NixOS/nixpkgs/blob/nixos-unstable/pkgs/applications/terminal-emulators/rio/default.nix)
- openSUSE package: [openSUSE:Factory/rioterm](https://software.opensuse.org/package/rioterm)
- Void Linux package: https://github.com/void-linux/void-packages/tree/master/srcpkgs/rio

In case your distro doesn't have the package manager option listed above, proceed to [build from the source](/docs/install/build-from-source).
