---
title: 'developer'
language: 'en'
---

This property enables log level filter and file. The default level is "OFF" and the logs are not logged to a file as default.

```toml
[developer]
log-level = "OFF"
enable-log-file = false
```

If you have any suggestion of configuration ideas to Rio, please feel free to [open an issue](https://github.com/raphamorim/rio/issues/new).
