---
title: 'Install'
language: 'en'
---

Rio is available for:

- [MacOS](/docs/install/macos)
- [Linux](/docs/install/linux)
- [Windows](/docs/install/windows)
- [FreeBSD](/docs/install/freebsd)
- [WebAssembly](/docs/install/webassembly)

Rio has two type of builds: stable and nightly.

While stable versions are thoroughly tested and takes longer to release, nightly versions are created on a daily basis.

[Github releases for Nightly](https://github.com/raphamorim/rio/releases/tag/nightly)
