---
title: 'Multi windows'
language: 'en'
---

The terminal supports multi window features in the following platforms: Windows, MacOS, FreeBSD and Linux.

<img src="https://miro.medium.com/v2/resize:fit:2914/format:webp/1*KyVD4EJ-wQU8pTmOFTwaQg.png" width="100%" />
