---
layout: post
title: 'Rio 0.0.11'
date: 2023-07-19 12:34
description: 'Performance improvements around 80-110%, binary size optimization, usage of pixel scale and others.'
categories: release windows macos linux
---

# v0.0.11: Changelog

Example of Rio v0.0.11 using the new sugarloaf:

v0.0.11 includes v0.0.10 with a bug fix of CachedSugar for font styles.

- Major rewrote of sugarloaf.
- Sugarloaf: Performance improvements around 80-110%.
- Sugarloaf: Introduced CachedSugar.
- Sugarloaf: Usage of PixelScale.
- Sugarloaf: Line-height support.
- Open new tab using the current tab directory.
- Fix some symbols break the horizontal and vertical alignment of lines (ref [#148](https://github.com/raphamorim/rio/issues/148)).
- Fix font size configuration is confusing (ref [#139](https://github.com/raphamorim/rio/issues/139)).
- Fix Glyph not rendered in prompt (ref: [#135](https://github.com/raphamorim/rio/issues/135)).
- Use fork by default in test context.
- Updated terminfo.
- Increased default font size to 18.
- Move to next and prev tab using keybindings.
- Setting editor by keybindings and new property called "editor" in configuration file.
- Rio creates ".deb" packages (canary and release).
- Binary size optimization (ref: [#152](https://github.com/raphamorim/rio/pull/152)) by [@OlshaMB](https://github.com/OlshaMB)
- A huge thanks to [@ralgozino](https://github.com/ralgozino) for all bug reporting and testing through this version development.
