---
layout: post
title: 'Release 0.0.5'
date: 2023-05-31 10:34:14 +0200
categories: macos linux release
description: 'Arrival to Linux, themes support and many bug fixes.'
---

# Arrival to Linux, Themes support and many bug fixes.

Rio release 0.0.5 is finally here, there's a lot of updates to cover so let's get started. I also would like to remind you that Rio is still unstable. This release adds a lot of bug fixes and feature additions in order to make Rio terminal stable.

## New configuration path

Configuration path has changed from `{$HOME}/.rio/` to `{$HOME}/.config/rio`.

Changes were applied for macOS and Linux.

## Linux Support

Rio is now available to Linux, build information was added in the [install](/docs/install) page.

![Linux support](/assets/posts/0.0.5/linux.jpeg)

Linux builds are considered less stable than macOs, due to macOs features availability comparison.

## Themes Support

A new property was added to Rio configuration file called "theme". You can set the theme that you want to use and Rio will look in the folder "themes" in the configuration path.

![Themes support](/assets/posts/0.0.5/themes.png)

Dracula theme example:

![Example dracula](/assets/posts/0.0.5/dracula-nvim.png)

## Bold and italic style

Support to text styling as such "bold" and "italic".

![Themes support](/assets/posts/0.0.5/font-macos.png)

## Changelog

- Fix to render specific 24bit colors [#66](https://github.com/raphamorim/rio/issues/#66) by [@niuez](https://github.com/niuez).
- Cross build for arm64 and x86
- Bold and Italic support [#33](https://github.com/raphamorim/rio/issues/#33).
- Add RioEvent::ColorRequest events to write color updates on pty.
- Theme support [#42](https://github.com/raphamorim/rio/issues/42).
- Fix font-size dependency for serialization
- Fix cursor visibility on VI mode and scroll [#51](https://github.com/raphamorim/#51)
- Performance fixes for rendering from teletypewriter updates.
- Fix scale issues for 1.0 scale factor or using monitor with different scale factor. [#50](https://github.com/raphamorim/rio/issues/#50)
- Improved release process to only contain Rio.app file. [#54](https://github.com/raphamorim/rio/issues/#54)
