---
title: 'Adaptive theme'
language: 'en'
---

### Adaptive theme

Rio support theme based on the system theme (light and dark). This configuration only works for Web, MacOS and Windows.

```toml
[adaptive-theme]
light = "belafonte-day"
dark = "belafonte-night"
```

Example of usage with MacOS:

![Adaptive theme](/assets/features/adaptive-theme.gif)
