---
layout: post
title: 'Looking ahead to 0.1.0'
date: 2024-04-18 00:34
description: "Let's talk about what's coming to Rio terminal"
categories: windows macos linux
---

import { Tweet } from 'react-tweet';

Hey there folks!

The Rio Terminal is a side project based on my free time (low this year due to being a new parent), when I started to work on Rio my goal was to learn mostly and eventually, I ended up using Rio in my daily life. However, the terminal wasn't designed to fit people's usage more than myself and would be quite hard to scale the source code to fit some of the feature requests, considering I never expected Rio to be used besides myself.

As I open-sourced Rio, many people started to use and eventually requests came in, making me realize that parts of the terminal would have to evolve to comprehend such requests and would eventually mean a rewrite of core parts along with incremental changes in other parts.

I have been working on 0.1.0 release since last December and still have a lot to be done ([Github backlog for 0.1.0](https://github.com/users/raphamorim/projects/6/views/1)). It is hard to give an estimation because there's no regular promised cadence and, I am not in a rush because it will require a lot of further testing and writing a lot of tests as well. Releases are likely to be made in small versions, is very likely that 0.1.0 will start with MacOS with Windows (I hope so at least).

Summary of 0.1.0 goals:

- Split screens.
- Stabilization of different fonts besides the default one.
- New windowing, migration from Winit to a project created for Rio purposes, called WA. WA uses gaming directives and is a mix of windowing architecture from [not-fl3/miniquad](https://github.com/not-fl3/miniquad) and [makepad/makepad](https://github.com/makepad/makepad) along with [winit](https://github.com/rust-windowing/winit).
- Sixel support.
- Font ligatures.
- Auto-Italicize and Auto-Bolding fonts.
- Addition of SIMD support for a few critical/repetitive operations.
- Emoji support.
- Give some love to Linux X11/Wayland to bring the native experience closer.

Note: Finally got a second computer with Windows/Linux, and it will make it insanely easier to work on Rio than I was doing before.

<Tweet id="1774416415073702204" />
