---
title: 'startup-directory'
language: 'en'
---

Directory the shell is started in. If this is unset the working directory of the parent process will be used.

This configuration only works if [`use-fork`](#use-fork) is disabled.

```toml
working-dir = "/Users/raphael/Documents/"
```
