---
title: 'padding'
language: 'en'
---

## Padding-x

Define x axis padding (default is 0)

```toml
padding-x = 10
```

## Padding-y

Define y axis padding based on a format `[top, left]`

- Default is `[0, 0]`

```toml
padding-y = [15, 10]
```