---
layout: post
title: 'Rio 0.0.8'
date: 2023-07-03 12:34
description: 'Support to Microsoft Windows, Homebrew casks and formulas, migration to Corcovado, selection improvements and increase/decrease font-size in a session.'
categories: release windows macos linux
---

import { Tweet } from 'react-tweet';

## v0.0.8: Highlights

- Support to Microsoft Windows.
- Support to Homebrew as cask [formulae.brew.sh/cask/rio](https://formulae.brew.sh/cask/rio).
- Support to Homebrew as formula [formulae.brew.sh/formula/rio](https://formulae.brew.sh/formula/rio).
- Selection improvements and increase/decrease font-size in a session.
- Migration to Corcovado.

<br />

# Overview

Rio release 0.0.8 is finally here, there's a lot of updates to cover so let's get started. I also would like to remind you that Rio is still unstable. This release adds a lot of bug fixes and feature additions in order to make Rio terminal stable.

## Microsoft Windows

Added support to Microsoft Windows.

Windows 10:
![Demo windows in use](/assets/posts/0.0.8/demo-windows-11.png)

Windows 11:
![Demo windows in search](/assets/posts/0.0.8/demo-windows-11.png)

## Homebrew as Cask

Homebrew is a free and open-source software package management system that simplifies the installation of software on Apple's operating system, macOS.

Rio has been added as a cask [formulae.brew.sh/cask/rio](https://formulae.brew.sh/cask/rio) to their package source. To install Rio with homebrew you need to run the command below:

```sh
brew update && brew install --cask rio
```

Github reference: [github.com/Homebrew/homebrew-cask/pull/149824](https://github.com/Homebrew/homebrew-cask/pull/149824)

## Homebrew as Formula

Rio has been added as a formula [formulae.brew.sh/formula/rio](https://formulae.brew.sh/formula/rio) to their package source. To install Rio with homebrew you need to run the command below:

```sh
brew update && brew install rio
```

Github reference: [github.com/Homebrew/homebrew-cask/pull/149824](https://github.com/Homebrew/homebrew-core/pull/134295)

## Selection improvements and increase/decrease font-size in a session

The version v0.0.8 has added the following missing functionalities: Scroll and select, Semantic and line selection and the ability to increase, decrease and reset font size using keyboard shortcut during session coming for Rio terminal.

Below you can see a demo with all those functionalities:

<Tweet id="1673705339336761344" />

## Migration to Corcovado

Rio terminal migrated from Mio to Corcovado. Corcovado is a maintained fork of mio 0.6.x along mio-signal-hook, mio-extras and using Windows API that works in Windows 11. It uses Rust edition 2021 instead of 2018.

Corcovado also uses Rust standard library for net and io instead of Mio 0.6.x.

<br />

## Changelog of v0.0.8

- Added generation of ".msi" and ".exe" files to the release pipeline (stable and canary).
- Support to Microsoft Windows 11.
- Ability to in/decrease font size using keyboard shortcut during session (ref: [#109](https://github.com/raphamorim/rio/issues/109))
- Inverted Canary and Stable icons.
- ANSI mouse reports (e.g: scroll and click working on VIM).
- Scroll and apply selection.
- Semantic and line selection.
- Rio is available in Homebrew casks and formulas.
- Rio stable versions are notarized now.
- Migration of mio, mio-extras, mio-signal-hook to Corcovado.
- Changed default black color to "#4c4345".
- Fix mouse position for when selecting text.
