---
title: 'iTerm2 Image Protocol'
language: 'en'
---

Rio implements support for the iTerm2 inline image protocol.

To render an image inline in your terminal, you can use `imgcat` provided as a script by iTerm2 in [iterm2.com/utilities/imgcat](https://iterm2.com/utilities/imgcat) or from other sources like:

- [pypi.org/project/imgcat](https://pypi.org/project/imgcat/)
- [npmjs.com/package/term-img](https://www.npmjs.com/package/term-img)
- [npmjs.com/package/imgcat](https://www.npmjs.com/package/imgcat)
- ... and etecetera.

![Demo iTerm2 image protocol](/assets/features/demo-iterm2-image-protocol.png)

More info regarding [iTerm image protocol](https://iterm2.com/documentation-images.html)
