---
title: 'Using cargo'
language: 'en'
---

Rio can be installed using Cargo, the package manager for Rust.

Cargo is available for most platforms, and is a good alternative to building Rio from source.

Rust and Cargo can be installed from [rust-lang.org](https://www.rust-lang.org/learn/get-started).

You might need to install additional packages depending on your platform. See the guide to [building from source](/docs/install/build-from-source) for more information.

```sh
cargo install rioterm
```

Then simply run `rio` to open the terminal.

```sh
rio
```
